# pc_perf
pc 进程性能测试平台，支持 windows / mac / linux 平台普通进程、window游戏GUI进程的
cpu、memory、fps（仅支持windowsOpenGL  DirectX 引擎应用）、gpu、thread_num、handle_num 等指标的实时监控和可视化展示

# 启动入口
    方式一：
    git clone https://github.com/15525730080/pc_perf.git
    pip install -r requirements.txt
    #需要使用管理员权限启动才可以获取到windows fps ！！！
    python pc_perf.py 
    
    方式二：
    #需要使用管理员权限启动才可以获取到windows fps ！！！
    pip install pc-perf
    python -m pc_perf  

    

# 创建任务
![image](https://github.com/15525730080/pc_perf/assets/153100629/91995e83-6fc6-4350-84d1-24704f1bccce)

# 任务列表
![image](https://github.com/15525730080/pc_perf/assets/153100629/10112d4b-3724-4ada-9cb8-df633af302a0)

# 性能报表
![image](https://github.com/15525730080/pc_perf/assets/153100629/2e28527a-6e5d-487c-8753-8d3483c0f108)

# 开源
本项目归属：范博洲  
使用需要关注开源协议
禁止申请软著、专利 本人已申请
